from distutils.core import setup

setup(
    name = 'datetimeformat_detector',
    packages = ['datetimeformat_detector'],
    version = 'v1.1',  # Ideally should be same as your GitHub release tag varsion
    description = 'Infer datetime format from datetime string',
    author = 'Zhuang Baokun',
    author_email = 'zhuangbaokun@gmail.com',
    url = 'https://github.com/zhuangbaokun/datetimeformat_detector',
    download_url = 'https://github.com/zhuangbaokun/datetimeformat_detector/archive/refs/tags/v1.1.tar.gz',
    keywords = ['datetime', 'format','detect','infer'],
    classifiers = [],
)